@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-xine.c,v 1.123 2004/07/22 17:59:01 hadess Exp $
+ * $Id: bacon-video-widget-xine.c,v 1.128 2004/09/15 11:47:42 hadess Exp $
  *
  * the xine engine in a widget - implementation
  */
@@ -699,36 +699,6 @@ bvw_config_helper_num (xine_t *xine, const char *id, int val,
 	}
 }
 
-static void
-setup_url_handlers (BaconVideoWidget *bvw, const char *protocol)
-{
-	char *key, *url;
-
-	key = g_strdup_printf ("/desktop/gnome/url-handlers/%s/command",
-			protocol);
-	url = gconf_client_get_string (bvw->priv->gc, key, NULL);
-
-	if (url == NULL)
-	{
-		gconf_client_set_string (bvw->priv->gc, key,
-				"totem \"%s\"", NULL);
-		g_free (key);
-
-		key = g_strdup_printf
-			("/desktop/gnome/url-handlers/%s/need-terminal",
-			 protocol);
-		gconf_client_set_bool (bvw->priv->gc, key, FALSE, NULL);
-		g_free (key);
-
-		key =  g_strdup_printf
-			("/desktop/gnome/url-handlers/%s/enabled", protocol);
-		gconf_client_set_bool (bvw->priv->gc, key, TRUE, NULL);
-		g_free (key);
-	}
-
-	g_free (url);
-}
-
 static void
 setup_config (BaconVideoWidget *bvw)
 {
@@ -774,11 +744,6 @@ setup_config (BaconVideoWidget *bvw)
 		return;
 	}
 
-	/* Setup the protocol handlers for our funky stuff */
-	setup_url_handlers (bvw, "pnm");
-	setup_url_handlers (bvw, "mms");
-	setup_url_handlers (bvw, "rtsp");
-
 	/* Proxy configuration */
 	if (gconf_client_get_bool (bvw->priv->gc, "/system/http_proxy/use_http_proxy", NULL) == FALSE)
 	{
@@ -1294,15 +1259,21 @@ xine_event_message (BaconVideoWidget *bvw, xine_ui_message_data_t *data)
 		message = g_strdup (_("The specified movie could not be found."));
 		break;
 	case XINE_MSG_READ_ERROR:
-		num = BVW_ERROR_READ_ERROR;
-		message = g_strdup (_("The movie could not be read."));
+		if (bvw->priv->mrl && g_str_has_prefix (bvw->priv->mrl, "dvd:") != FALSE)
+                {
+                        num = BVW_ERROR_DVD_ENCRYPTED;
+                        message = g_strdup (_("The source seems encrypted, and can't be read. Are you trying to play an encrypted DVD without libdvdcss?"));
+                } else {
+			num = BVW_ERROR_READ_ERROR;
+			message = g_strdup (_("The movie could not be read."));
+		}
 		break;
 	case XINE_MSG_LIBRARY_LOAD_ERROR:
 		num = BVW_ERROR_PLUGIN_LOAD;
 		message = g_strdup_printf (_("A problem occured while loading a library or a decoder (%s)."), (char *) data + data->parameters);
 		break;
 	case XINE_MSG_ENCRYPTED_SOURCE:
-		if (strncmp (bvw->priv->mrl, "dvd:", 4) == 0)
+		if (g_str_has_prefix (bvw->priv->mrl, "dvd:") != FALSE)
 		{
 			num = BVW_ERROR_DVD_ENCRYPTED;
 			message = g_strdup (_("The source seems encrypted, and can't be read. Are you trying to play an encrypted DVD without libdvdcss?"));
@@ -1322,7 +1293,7 @@ xine_event_message (BaconVideoWidget *bvw, xine_ui_message_data_t *data)
 		break;
 	case XINE_MSG_PERMISSION_ERROR:
 		num = BVW_ERROR_FILE_PERMISSION;
-		if (strncmp (bvw->priv->mrl, "file:", 5) == 0)
+		if (g_str_has_prefix (bvw->priv->mrl, "file:") != FALSE)
 			message = g_strdup (_("You are not allowed to open this file."));
 		else
 			message = g_strdup (_("The server refused access to this file or stream."));
@@ -1898,8 +1869,6 @@ bacon_video_widget_open (BaconVideoWidget *bvw, const char *mrl,
 		return FALSE;
 	}
 
-	g_message ("XINE_META_INFO_SYSTEMLAYER: %s", xine_get_meta_info (bvw->priv->stream, XINE_META_INFO_SYSTEMLAYER));
-
 	if (xine_get_stream_info (bvw->priv->stream,
 				XINE_STREAM_INFO_VIDEO_HANDLED) == FALSE
 			|| (xine_get_stream_info (bvw->priv->stream,
@@ -1914,10 +1883,11 @@ bacon_video_widget_open (BaconVideoWidget *bvw, const char *mrl,
 
 		name = g_strdup (xine_get_meta_info (bvw->priv->stream,
 				XINE_META_INFO_VIDEOCODEC));
-		if (name == NULL)
+		if (name == NULL || name[0] == '\0')
 		{
 			guint32 video_fcc;
 
+			g_free (name);
 			video_fcc = xine_get_stream_info (bvw->priv->stream,
 					XINE_STREAM_INFO_VIDEO_FOURCC);
 			name = get_fourcc_string (video_fcc);
@@ -2204,6 +2174,7 @@ bacon_video_widget_set_logo (BaconVideoWidget *bvw, char *filename)
 	g_return_if_fail (bvw != NULL);
 	g_return_if_fail (BACON_IS_VIDEO_WIDGET(bvw));
 	g_return_if_fail (bvw->priv->xine != NULL);
+	g_return_if_fail (filename != NULL);
 
 	if (bacon_video_widget_open (bvw, filename, NULL) != FALSE) {
 		bacon_video_widget_play (bvw, NULL);
