@@ -29,13 +29,38 @@
 #include <glib.h>
 
 typedef enum {
-	CDDRIVE_TYPE_FILE,
-	CDDRIVE_TYPE_CD_RECORDER,
-	CDDRIVE_TYPE_DVD_RECORDER,
-	CDDRIVE_TYPE_CD_DRIVE,
-	CDDRIVE_TYPE_DVD_DRIVE,
+	CD_MEDIA_TYPE_BUSY,
+	CD_MEDIA_TYPE_ERROR,
+	CD_MEDIA_TYPE_UNKNOWN,
+	CD_MEDIA_TYPE_CD,
+	CD_MEDIA_TYPE_CDR,
+	CD_MEDIA_TYPE_CDRW,
+	CD_MEDIA_TYPE_DVD,
+	CD_MEDIA_TYPE_DVDR,
+	CD_MEDIA_TYPE_DVDRW,
+	CD_MEDIA_TYPE_DVD_RAM,
+	CD_MEDIA_TYPE_DVD_PLUS_R,
+	CD_MEDIA_TYPE_DVD_PLUS_RW,
+} CDMediaType;
+
+typedef enum {
+	CDDRIVE_TYPE_FILE                   = 1 << 0,
+	CDDRIVE_TYPE_CD_RECORDER            = 1 << 1,
+	CDDRIVE_TYPE_CDRW_RECORDER          = 1 << 2,
+	CDDRIVE_TYPE_DVD_RAM_RECORDER       = 1 << 3,
+	/* Drives are usually DVD-R and DVD-RW */
+	CDDRIVE_TYPE_DVD_RW_RECORDER        = 1 << 4,
+	CDDRIVE_TYPE_DVD_PLUS_R_RECORDER    = 1 << 5,
+	CDDRIVE_TYPE_DVD_PLUS_RW_RECORDER   = 1 << 6,
+	CDDRIVE_TYPE_CD_DRIVE               = 1 << 7,
+	CDDRIVE_TYPE_DVD_DRIVE              = 1 << 8,
 } CDDriveType;
 
+typedef enum {
+	CD_PROTOCOL_IDE,
+	CD_PROTOCOL_SCSI,
+} CDProtocolType;
+
 typedef struct {
 	CDDriveType type;
 	char *display_name;
@@ -43,10 +68,14 @@ typedef struct {
 	int max_speed_read;
 	char *cdrecord_id;
 	char *device;
+	CDProtocolType protocol;
 } CDDrive;
 
 /* Returns a list of CDDrive structs */
 GList *scan_for_cdroms (gboolean recorder_only, gboolean add_image);
 void cd_drive_free (CDDrive *drive);
+CDMediaType cd_drive_get_media_type (CDDrive *drive);
+CDMediaType cd_drive_get_media_type_from_path (const char *device_path);
+CDDrive *cd_drive_get_file_image (void);
 
 #endif
