@@ -49,6 +49,7 @@ typedef TotemPlParserResult (*PlaylistCallback) (TotemPlParser *parser, const ch
 static gboolean totem_pl_parser_scheme_is_ignored (TotemPlParser *parser, const char *url);
 static gboolean totem_pl_parser_ignore (TotemPlParser *parser, const char *url);
 static TotemPlParserResult totem_pl_parser_parse_internal (TotemPlParser *parser, const char *url);
+static TotemPlParserResult totem_pl_parser_add_asx (TotemPlParser *parser, const char *url, gpointer data);
 
 typedef struct {
 	char *mimetype;
@@ -663,18 +664,19 @@ totem_pl_parser_add_asf_parser (TotemPlParser *parser, const char *url,
 
 	ref = read_ini_line_string (lines, "Ref1", FALSE);
 
-	if (ref == NULL)
-		goto bail;
+	if (ref == NULL) {
+		g_strfreev (lines);
+		return totem_pl_parser_add_asx (parser, url, data);
+	}
 
 	/* change http to mms, thanks Microsoft */
-	if (strncmp ("http", ref, 4) == 0)
+	if (g_str_has_prefix (ref, "http") != FALSE)
 		memcpy(ref, "mmsh", 4);
 
 	totem_pl_parser_add_one_url (parser, ref, NULL);
 	retval = TOTEM_PL_PARSER_RESULT_SUCCESS;
 	g_free (ref);
 
-bail:
 	g_strfreev (lines);
 
 	return retval;
@@ -878,9 +880,9 @@ static TotemPlParserResult
 totem_pl_parser_add_ra (TotemPlParser *parser, const char *url, gpointer data)
 {
 	if (data == NULL
-			|| (strncmp (data, "http://", strlen ("http://")) != 0
-			&& strncmp (data, "rtsp://", strlen ("rtsp://")) != 0
-			    && strncmp (data, "pnm://", strlen ("pnm://")) != 0)) {
+			|| (g_str_has_prefix (data, "http://") == FALSE
+			&& g_str_has_prefix (data, "rtsp://") == FALSE
+			&& g_str_has_prefix (data, "pnm://") == FALSE)) {
 		totem_pl_parser_add_one_url (parser, url, NULL);
 		return TOTEM_PL_PARSER_RESULT_SUCCESS;
 	}
@@ -1011,12 +1013,8 @@ totem_pl_parser_add_smil (TotemPlParser *parser, const char *url, gpointer data)
 static TotemPlParserResult
 totem_pl_parser_add_asf (TotemPlParser *parser, const char *url, gpointer data)
 {
-	if (data == NULL) {
-		totem_pl_parser_add_one_url (parser, url, NULL);
-		return TOTEM_PL_PARSER_RESULT_SUCCESS;
-	}
-
-	if (strncmp (data, "[Reference]", strlen ("[Reference]")) != 0) {
+	if (data != NULL &&
+		g_str_has_prefix (data, "[Reference]") == FALSE) {
 		totem_pl_parser_add_one_url (parser, url, NULL);
 		return TOTEM_PL_PARSER_RESULT_SUCCESS;
 	}
@@ -1157,7 +1155,7 @@ totem_pl_parser_scheme_is_ignored (TotemPlParser *parser, const char *url)
 	for (l = parser->priv->ignore_schemes; l != NULL; l = l->next)
 	{
 		const char *scheme = l->data;
-		if (strncmp (url, scheme, strlen (scheme)) == 0)
+		if (g_str_has_prefix (url, scheme) != FALSE)
 			return TRUE;
 	}
 
@@ -1203,7 +1201,7 @@ totem_pl_parser_parse_internal (TotemPlParser *parser, const char *url)
 	gpointer data = NULL;
 	gboolean ret = FALSE;
 
-	if (parser->priv->recurse_level > 3)
+	if (parser->priv->recurse_level > 4)
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 
 	parser->priv->recurse_level++;
@@ -1252,7 +1250,7 @@ totem_pl_parser_parse (TotemPlParser *parser, const char *url,
 	g_return_val_if_fail (TOTEM_IS_PL_PARSER (parser), TOTEM_PL_PARSER_RESULT_UNHANDLED);
 	g_return_val_if_fail (url != NULL, TOTEM_PL_PARSER_RESULT_UNHANDLED);
 
-	parser->priv->recurse_level = 1;
+	parser->priv->recurse_level = 0;
 	parser->priv->fallback = fallback;
 	return totem_pl_parser_parse_internal (parser, url);
 }
